@@ -1,17 +1,16 @@
 #! /usr/bin/perl -w
 #
-#     Shorewall Packet Filtering Firewall configuration program - V5.2
+#     Shorewall Packet Filtering Firewall RPM configuration program - V4.5
 #
-#     (c) 2012, 2014 - Tom Eastep (teastep@shorewall.net)
+#     This program is under GPL [http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt]
+#
+#     (c) 2012 - Tom Eastep (teastep@shorewall.net)
 #
 #	Shorewall documentation is available at http://www.shorewall.net
 #
-#       This program is part of Shorewall.
-#
 #	This program is free software; you can redistribute it and/or modify
-#	it under the terms of the GNU General Public License as published by the
-#       Free Software Foundation, either version 2 of the license or, at your
-#       option, any later version.
+#	it under the terms of Version 2 of the GNU General Public License
+#	as published by the Free Software Foundation.
 #
 #	This program is distributed in the hope that it will be useful,
 #	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,7 +18,8 @@
 #	GNU General Public License for more details.
 #
 #	You should have received a copy of the GNU General Public License
-#	along with this program; if not, see <http://www.gnu.org/licenses/>.
+#	along with this program; if not, write to the Free Software
+#	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 #       Usage: ./configure.pl <option>=<setting> ...
 #
@@ -31,7 +31,7 @@ use strict;
 # Build updates this
 #
 use constant {
-    VERSION => '5.2.3.2'
+    VERSION => '4.5.21.6'
 };
 
 my %params;
@@ -52,9 +52,6 @@ for ( @ARGV ) {
     $params{$pn} = $pv;
 }
 
-use File::Basename;
-chdir dirname($0);
-
 my $vendor = $params{HOST};
 my $rcfile;
 my $rcfilename;
@@ -67,61 +64,27 @@ unless ( defined $vendor ) {
 
 	$id =~ s/ID=//;
 	
-	if ( $id eq 'fedora' || $id eq 'rhel' ) {
+	if ( $id eq 'fedora' ) {
 	    $vendor = 'redhat';
 	} elsif ( $id eq 'opensuse' ) {
 	    $vendor = 'suse';
-	} elsif ( $id eq 'ubuntu' || $id eq 'debian' ) {
-	    my $init = `ls -l /sbin/init`;
-	    $vendor = $init =~ /systemd/ ? 'debian.systemd' : 'debian.sysvinit';
-	} elsif ( $id eq 'alt' || $id eq 'basealt' || $id eq 'altlinux' ) {
-	    $vendor = 'alt';
+	} elsif ( $id eq 'ubuntu' ) {
+	    $vendor = 'debian';
 	} else {
 	    $vendor = $id;
 	}
     }
 
     $params{HOST} = $vendor;
-    $params{HOST} =~ s/\..*//;
 }
 
 if ( defined $vendor ) {
-    if ( $vendor eq 'debian' && -f '/etc/debian_version' ) {
-	if ( -l '/sbin/init' ) {
-	    if ( readlink('/sbin/init') =~ /systemd/ ) {
-		$rcfilename = 'shorewallrc.debian.systemd';
-	    } else {
-		$rcfilename = 'shorewallrc.debian.sysvinit';
-	    }
-	} else {
-	    $rcfilename = 'shorewallrc.debian.sysvinit';
-	}
-    } else {
-	$rcfilename = $vendor eq 'linux' ? 'shorewallrc.default' : 'shorewallrc.' . $vendor;
-    }
-
-    unless ( -f $rcfilename ) {
-	die qq("ERROR: $vendor" is not a recognized host type);
-    } elsif ( $vendor eq 'default' ) {
-	$params{HOST} = $vendor = 'linux';
-    } elsif ( $vendor =~ /^debian\./ ) {
-	$params{HOST} = $vendor = 'debian';
-    }
+    $rcfilename = $vendor eq 'linux' ? 'shorewallrc.default' : 'shorewallrc.' . $vendor;
+    die qq("ERROR: $vendor" is not a recognized host type) unless -f $rcfilename;
 } else {
     if ( -f '/etc/debian_version' ) {
 	$vendor = 'debian';
-	if ( -l '/sbin/init' ) {
-	    if ( readlink( '/sbin/init' ) =~ /systemd/ ) {
-		$rcfilename = 'shorewallrc.debian.systemd';
-	    } else {
-		$rcfilename = 'shorewallrc.debian.sysvinit';
-	    }
-	} else {
-	    $rcfilename = 'shorewallrc.debian.sysvinit';
-	}
-    } elsif ( -f '/etc/altlinux-release' ){
-	$vendor = 'alt';
-	$rcfilename = 'shorewallrc.alt';
+	$rcfilename = 'shorewallrc.debian';
     } elsif ( -f '/etc/redhat-release' ){
 	$vendor = 'redhat';
 	$rcfilename = 'shorewallrc.redhat';
@@ -137,7 +100,7 @@ if ( defined $vendor ) {
     } elsif ( `uname` =~ '^Darwin' ) {
 	$vendor = 'apple';
 	$rcfilename = 'shorewallrc.apple';
-    } elsif ( `uname` =~ /^Cygwin/i ) {
+    } elsif ( `uname` =~ '^Cygwin' ) {
 	$vendor = 'cygwin';
 	$rcfilename = 'shorewallrc.cygwin';
     } else {
@@ -154,7 +117,7 @@ my @abbr = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
 if ( $vendor eq 'linux' ) {
     printf "INFO: Creating a generic Linux installation - %s %2d %04d %02d:%02d:%02d\n\n", $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];;
 } else {
-    printf "INFO: Creating a %s-specific installation - %s %2d %04d %02d:%02d:%02d\n\n", $params{HOST}, $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];;
+    printf "INFO: Creating a %s-specific installation - %s %2d %04d %02d:%02d:%02d\n\n", $vendor, $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];;
 }
 
 open $rcfile, '<', $rcfilename or die "Unable to open $rcfilename for input: $!";
@@ -178,13 +141,7 @@ my $outfile;
 
 open $outfile, '>', 'shorewallrc' or die "Can't open 'shorewallrc' for output: $!";
 
-if ( $ENV{SOURCE_DATE_EPOCH} ) {
-    printf $outfile "#\n# Created by Shorewall Core version %s configure.pl - %s\n", VERSION, `date  --utc --date=\"\@$ENV{SOURCE_DATE_EPOCH}\"`;
-} else {
-    printf $outfile "#\n# Created by Shorewall Core version %s configure.pl - %s %2d %04d %02d:%02d:%02d\n", VERSION, $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];
-}
-
-print $outfile "# rc file: $rcfilename\n#\n";
+printf $outfile "#\n# Created by Shorewall Core version %s configure.pl - %s %2d %04d %02d:%02d:%02d\n#\n", VERSION, $abbr[$localtime[4]], $localtime[3], 1900 + $localtime[5] , @localtime[2,1,0];
 
 print  $outfile "# Input: @ARGV\n#\n" if @ARGV;
 
@@ -197,8 +154,6 @@ if ( $options{VARLIB} ) {
     $options{VARDIR} = '${VARLIB}/${PRODUCT}';
 }
 
-$options{SERVICEDIR}=$options{SYSTEMD} unless $options{SERVICEDIR};
-
 for ( qw/ HOST
 	  PREFIX
 	  SHAREDIR
@@ -212,15 +167,14 @@ for ( qw/ HOST
 	  INITFILE
 	  AUXINITSOURCE
 	  AUXINITFILE
-	  SERVICEDIR
-	  SERVICEFILE
+	  SYSTEMD
+          SERVICEFILE
 	  SYSCONFFILE
 	  SYSCONFDIR
 	  SPARSE
 	  ANNOTATED
 	  VARLIB
-	  VARDIR
-          DEFAULT_PAGER / ) {
+	  VARDIR / ) {
 
     my $val = $options{$_} || '';
 
