@@ -1,10 +1,10 @@
 #!/bin/sh
 #
-#     The Shoreline Firewall (Shorewall) Packet Filtering Firewall - V5.2
+#     The Shoreline Firewall (Shorewall6) Packet Filtering Firewall - V4.5
 #
 #     This program is under GPL [http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt]
 #
-#     (c) 1999,2000,2001,2002,2003,2004,2005 - Tom Eastep (teastep@shorewall.net)
+#     (c) 1999,2000,2001,2002,2003,2004,2005,2012 - Tom Eastep (teastep@shorewall.net)
 #
 #	On most distributions, this file should be called /etc/init.d/shorewall.
 #
@@ -28,29 +28,31 @@
 #
 #	Commands are:
 #
-#	   shorewall start			  Starts the firewall
-#	   shorewall restart			  Restarts the firewall
-#	   shorewall reload			  Reload the firewall
-#	   shorewall stop			  Stops the firewall
-#	   shorewall status			  Displays firewall status
+#	   shorewall6 start			  Starts the firewall
+#	   shorewall6 restart			  Restarts the firewall
+#	   shorewall6 reload			  Reload the firewall
+#						  (same as restart)
+#	   shorewall6 stop			  Stops the firewall
+#	   shorewall6 status			  Displays firewall status
 #
 
 ### BEGIN INIT INFO
-# Provides:          shorewall
-# Required-Start:    $network $remote_fs
-# Required-Stop:     $network $remote_fs
-# Default-Start:     2 3 5
-# Default-Stop:      0 6
-# Short-Description: Configure the firewall at boot time
-# Description:       Configure the firewall according to the rules specified in
-#                    /etc/shorewall
+# Provides:	  shorewall6
+# Required-Start: $local_fs $remote_fs $syslog
+# Should-Start: VMware $time $named
+# Should-Stop:  $null
+# Required-Stop: $null
+# Default-Start:  2 3 5
+# Default-Stop:	  0 1 6
+# Description:	  starts and stops the shorewall6 firewall
+# Short-Description: Packet filtering firewall
 ### END INIT INFO
 
 ################################################################################
 # Give Usage Information						       #
 ################################################################################
 usage() {
-    echo "Usage: $0 start|stop|reload|restart|status" >&2
+    echo "Usage: $0 start|stop|reload|restart|status"
     exit 1
 }
 
@@ -64,30 +66,22 @@ OPTIONS="-v0"
 #
 . /usr/share/shorewall/shorewallrc
 
-if [ -f ${SYSCONFDIR}/shorewall ]; then
-    . ${SYSCONFDIR}/shorewall
-fi
-
 export SHOREWALL_INIT_SCRIPT=1
 
 ################################################################################
 # E X E C U T I O N    B E G I N S   H E R E				       #
 ################################################################################
 command="$1"
-shift
 
 case "$command" in
     start)
-	exec $SBINDIR/shorewall $OPTIONS start $STARTOPTIONS
+	exec ${SBINDIR}/shorewall6 $OPTIONS start $STARTOPTIONS
 	;;
-    reload)
-	exec $SBINDIR/shorewall $OPTIONS restart $RELOADOPTIONS
-	;;
-    restart)
-	exec $SBINDIR/shorewall $OPTIONS restart $RESTARTOPTIONS
+    restart|reload)
+	exec ${SBINDIR}/shorewall6 $OPTIONS restart $RESTARTOPTIONS
 	;;
     status|stop)
-	exec $SBINDIR/shorewall $OPTIONS $command
+	exec ${SBINDIR}/shorewall6 $OPTIONS $command $@
 	;;
     *)
 	usage
